@@ -5,7 +5,6 @@ compas_plotters
 
 .. currentmodule:: compas_plotters
 
-
 Classes
 =======
 
@@ -13,25 +12,21 @@ Classes
     :toctree: generated/
     :nosignatures:
 
+    GeometryPlotter
     NetworkPlotter
     MeshPlotter
 
+
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-
-
-__version__ = '0.16.0'
-
+__version__ = '0.17.3'
 
 from .core import *  # noqa: F401 F403
 from .artists import *  # noqa: F401 F403
 
-from .plotter import Plotter  # noqa: F401
-from .plotter2 import Plotter2  # noqa: F401
+from .geometryplotter import GeometryPlotter  # noqa: F401
 
+from .plotter import Plotter  # noqa: F401
 from .networkplotter import NetworkPlotter  # noqa: F401
 from .meshplotter import MeshPlotter  # noqa: F401
 
